@@ -4,7 +4,7 @@
   Copyright (c) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
   Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (C) 2009 Sebastian Sauer <sebsauer@kdab.net>
-  Copyright (c) 2010-2016 Laurent Montel <montel@kde.org>
+  Copyright (c) 2010-2017 Laurent Montel <montel@kde.org>
   Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@
 #include "kohelper.h"
 #include "prefs/koprefs.h"
 #include "koglobals.h"
+#include "manageshowcollectionproperties.h"
 #include "views/collectionview/reparentingmodel.h"
 #include "views/collectionview/calendardelegate.h"
 #include "views/collectionview/quickview.h"
@@ -50,8 +51,8 @@
 #include <AkonadiWidgets/ETMViewStateSaver>
 #include <Akonadi/Calendar/StandardCalendarActionManager>
 #include <AkonadiCore/CollectionIdentificationAttribute>
-#include <pimcommon/manageserversidesubscriptionjob.h>
-#include "PimCommon/PimUtil"
+#include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
+#include "PimCommonAkonadi/MailUtil"
 
 #include <KActionCollection>
 #include <KCheckableProxyModel>
@@ -236,7 +237,7 @@ private:
 };
 
 AkonadiCollectionViewFactory::AkonadiCollectionViewFactory(CalendarView *view)
-    : mView(view), mAkonadiCollectionView(Q_NULLPTR)
+    : mView(view), mAkonadiCollectionView(nullptr)
 {
 }
 
@@ -266,7 +267,7 @@ static bool hasCompatibleMimeTypes(const Akonadi::Collection &collection)
 class SortProxyModel : public QSortFilterProxyModel
 {
 public:
-    explicit SortProxyModel(QObject *parent = Q_NULLPTR)
+    explicit SortProxyModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
     {
         setDynamicSortFilter(true);
@@ -304,7 +305,7 @@ public:
 class ColorProxyModel : public QSortFilterProxyModel
 {
 public:
-    explicit ColorProxyModel(QObject *parent = Q_NULLPTR)
+    explicit ColorProxyModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent), mInitDefaultCalendar(false)
     {
     }
@@ -353,7 +354,7 @@ private:
 class CollectionFilter : public QSortFilterProxyModel
 {
 public:
-    explicit CollectionFilter(QObject *parent = Q_NULLPTR)
+    explicit CollectionFilter(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
     {
         setDynamicSortFilter(true);
@@ -378,7 +379,7 @@ protected:
 class EnabledModel : public QSortFilterProxyModel
 {
 public:
-    explicit EnabledModel(QObject *parent = Q_NULLPTR)
+    explicit EnabledModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
     {
     }
@@ -402,7 +403,7 @@ protected:
 class CalendarDelegateModel : public QSortFilterProxyModel
 {
 public:
-    explicit CalendarDelegateModel(QObject *parent = Q_NULLPTR)
+    explicit CalendarDelegateModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
     {
     }
@@ -499,19 +500,21 @@ AkonadiCollectionView *AkonadiCollectionViewFactory::collectionView() const
 AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContextMenu,
         QWidget *parent)
     : CalendarViewExtension(parent),
-      mActionManager(Q_NULLPTR),
-      mCollectionView(Q_NULLPTR),
-      mBaseModel(Q_NULLPTR),
-      mSelectionProxyModel(Q_NULLPTR),
-      mAssignColor(Q_NULLPTR),
-      mDisableColor(Q_NULLPTR),
-      mDefaultCalendar(Q_NULLPTR),
-      mEnableAction(Q_NULLPTR),
-      mServerSideSubscription(Q_NULLPTR),
+      mActionManager(nullptr),
+      mCollectionView(nullptr),
+      mBaseModel(nullptr),
+      mSelectionProxyModel(nullptr),
+      mAssignColor(nullptr),
+      mDisableColor(nullptr),
+      mDefaultCalendar(nullptr),
+      mEnableAction(nullptr),
+      mServerSideSubscription(nullptr),
       mNotSendAddRemoveSignal(false),
       mWasDefaultCalendar(false),
       mHasContextMenu(hasContextMenu)
 {
+    mManagerShowCollectionProperties = new ManageShowCollectionProperties(this, this);
+
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     topLayout->setMargin(0);
 
@@ -665,12 +668,8 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
         mActionManager->action(Akonadi::StandardActionManager::CreateCollection)->setProperty("ContentMimeTypes",
                 QStringList() << Akonadi::Collection::mimeType() << KCalCore::Event::eventMimeType());
 
-        const QStringList pages =
-            QStringList() << QStringLiteral("CalendarSupport::CollectionGeneralPage")
-            << QStringLiteral("Akonadi::CachePolicyPage")
-            << QStringLiteral("PimCommon::CollectionAclPage");
-
-        mActionManager->setCollectionPropertiesPageNames(pages);
+        mActionManager->interceptAction(Akonadi::StandardActionManager::CollectionProperties);
+        connect(mActionManager->action(Akonadi::StandardActionManager::CollectionProperties), &QAction::triggered, mManagerShowCollectionProperties, &ManageShowCollectionProperties::showCollectionProperties);
 
         mDisableColor = new QAction(mCollectionView);
         mDisableColor->setText(i18n("&Disable Color"));
@@ -737,6 +736,14 @@ void AkonadiCollectionView::slotServerSideSubscription()
     job->start();
 }
 
+Akonadi::Collection AkonadiCollectionView::currentCalendar() const
+{
+    const QModelIndex index = mCollectionView->selectionModel()->currentIndex(); //selectedRows()
+    Q_ASSERT(index.isValid());
+    Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
+    return collection;
+}
+
 void AkonadiCollectionView::setDefaultCalendar()
 {
     QModelIndex index = mCollectionView->selectionModel()->currentIndex(); //selectedRows()
@@ -851,7 +858,7 @@ void AkonadiCollectionView::updateMenu()
             mEnableAction->setEnabled(true);
         }
         bool isOnline;
-        mServerSideSubscription->setEnabled(PimCommon::Util::isImapFolder(collection, isOnline));
+        mServerSideSubscription->setEnabled(PimCommon::MailUtil::isImapFolder(collection, isOnline));
     } else {
         mServerSideSubscription->setEnabled(false);
     }
@@ -980,10 +987,10 @@ Akonadi::Collection::List AkonadiCollectionView::checkedCollections() const
     if (!selectionModel) {
         return collections;
     }
-    QModelIndexList indexes = selectionModel->selectedIndexes();
-    foreach (const QModelIndex &index, indexes) {
+    const QModelIndexList indexes = selectionModel->selectedIndexes();
+    for (const QModelIndex &index : indexes) {
         if (index.isValid()) {
-            Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (collection.isValid()) {
                 collections << collection;
             }
@@ -1001,10 +1008,10 @@ bool AkonadiCollectionView::isChecked(const Akonadi::Collection &collection) con
     if (!selectionModel) {
         return false;
     }
-    QModelIndexList indexes = selectionModel->selectedIndexes();
-    foreach (const QModelIndex &index, indexes) {
+    const QModelIndexList indexes = selectionModel->selectedIndexes();
+    for (const QModelIndex &index : indexes) {
         if (index.isValid()) {
-            Akonadi::Collection c = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            const Akonadi::Collection c = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (c.id() == collection.id()) {
                 return true;
             }
@@ -1025,7 +1032,7 @@ Akonadi::EntityTreeModel *AkonadiCollectionView::entityTreeModel() const
     }
 
     qCWarning(KORGANIZER_LOG) << "Couldn't find EntityTreeModel";
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void AkonadiCollectionView::edit_disable()
@@ -1119,6 +1126,10 @@ void AkonadiCollectionView::onAction(const QModelIndex &index, int a)
         }
     }
     break;
+    case StyledCalendarDelegate::Total: {
+        //TODO: anything to implement here?
+    }
+    break;
     }
 }
 
